@@ -45,8 +45,9 @@ def get_andlos_list_skills(parse_github=False, skiplist=None):
 
 
 class AndloSkillList(AbstractAppstore):
-    def __init__(self, parse_github=False):
-        super().__init__("AndloSkillList", parse_github)
+    def __init__(self, *args, **kwargs):
+        super().__init__("AndloSkillList", appstore_id="andlo",
+                         *args, **kwargs)
 
     def get_skills_list(self, skiplist=None):
         skiplist = skiplist or []
